package ballerina.lang.jsons;

@doc:Description ("Inserts a Boolean to a JSON array. This function will add a new Boolean element to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A Boolean value" )
native function add (json j, string jsonPath, boolean value);

@doc:Description ("Inserts a named element to a JSON object. This function will add a new Boolean element with the given name (key) to the location identified by the given JSONPath.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: A Boolean value" )
native function add (json j, string jsonPath, string key, boolean value);

@doc:Description ("Inserts a double to a JSON array. This function will add a new double value to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A double value" )
native function add (json j, string jsonPath, double value);

@doc:Description ("Inserts a named element to a JSON object. This function will add a new double element with the given name (key) to the location identified by the given JSONPath. If an element with the same name already exists, it will update the value of the existing element.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: A double value" )
native function add (json j, string jsonPath, string key, double value);

@doc:Description ("Inserts a float to a JSON array. This function will add a new float element to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A float value" )
native function add (json j, string jsonPath, float value);

@doc:Description ("Inserts a named element to a JSON object. This function will add a new float element with the given name (key)")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: A float value" )
native function add (json j, string jsonPath, string key, float value);

@doc:Description ("Inserts an integer element to a JSON array. This function will add a new integer element to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: An integer value" )
native function add (json j, string jsonPath, int value);

@doc:Description ("Inserts a named element to a JSON object. This function will add a new integer element with the given name (key)")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: An integer value" )
native function add (json j, string jsonPath, string key, int value);

@doc:Description ("Inserts a JSON element to a JSON array. This function will add a new JSON element to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: The JSON element to be added" )
native function add (json j, string jsonPath, json value);

@doc:Description ("Inserts a named element to a JSON object. This method will add a new JSON element with the given name (key)")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: A JSON value" )
native function add (json j, string jsonPath, string key, json value);

@doc:Description ("Inserts an element to a JSON array. This function will add a new string element to the end of the JSON array identified by the given JSONPath.")
@doc:Param ("j: A JSON array object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A string value" )
native function add (json j, string jsonPath, string value);

@doc:Description ("Inserts a named element to a JSON object. This function will add a new string element with the given name (key)")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("key: The name of the element to be added" )
@doc:Param ("value: A string value" )
native function add (json j, string jsonPath, string key, string value);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the Boolean value.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("boolean: The Boolean element on the specified path " )
native function getBoolean (json j, string jsonPath) (boolean);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the double value.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("double: The double element on the specified path" )
native function getDouble (json j, string jsonPath) (double);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the integer value.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("float: The float element on the specified path" )
native function getFloat (json j, string jsonPath) (float);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the integer value.")
@doc:Param ("j: A json object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("int: The integer element on the specified path" )
native function getInt (json j, string jsonPath) (int);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the matching JSON.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("json: The JSON element on the specified path" )
native function getJson (json j, string jsonPath) (json);

@doc:Description ("Evaluates the JSONPath on a JSON object and returns the string value")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Return ("string: The string element on the specified path" )
native function getString (json j, string jsonPath) (string);

@doc:Description ("Removes each element that matches the given JSONPath.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
native function remove (json j, string jsonPath);

@doc:Description ("Renames the key of the given element that is under the given JSONPath.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("oldKey: The old key value" )
@doc:Param ("newKey: The new key value to use" )
native function rename (json j, string jsonPath, string oldKey, string newKey);

@doc:Description ("Sets the Boolean value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A Boolean value" )
native function set (json j, string jsonPath, boolean value);

@doc:Description ("Sets the double value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A double value" )
native function set (json j, string jsonPath, double value);

@doc:Description ("Sets the float value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A float value" )
native function set (json j, string jsonPath, float value);

@doc:Description ("Sets the integer value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: An integer value" )
native function set (json j, string jsonPath, int value);

@doc:Description ("Sets the JSON value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A JSON value" )
native function set (json j, string jsonPath, json value);

@doc:Description ("Sets the string value of the element that matches the given JSONPath. If the JSONPath doesn't match any element, this operation will have no effect.")
@doc:Param ("j: A JSON object" )
@doc:Param ("jsonPath: The path of the JSON element" )
@doc:Param ("value: A string value" )
native function set (json j, string jsonPath, string value);

@doc:Description ("Converts a JSON object to a string representation")
@doc:Param ("j: A JSON object" )
@doc:Return ("string: String value of the converted JSON" )
native function toString (json j) (string);

